@@ -29,6 +29,8 @@ def get_poem_map():
     dfs = []
     for file in ['poem_ext.txt', 'cangtoushi7.txt', 'cangtoushi5.txt']:
         df = pd.read_csv(data_cache / file, '\t', names=['char', 'poems'])
+        if file == 'cangtoushi5.txt':
+            df['poems'] = df['poems'].str.split().str[0]
         dfs.append(df)
     df = (
         pd.concat(dfs)
@@ -67,14 +69,14 @@ async def read_item(title):
     return {"title": title, "poem": poem_gen(title)}
 
 
-if __name__ == '__main__':
-    import os
-    import socket
-
-    me = socket.gethostname() == 'yuanjie-Mac.local'
-    gunicorn = "gunicorn" if me else "/opt/soft/python3/bin/gunicorn"
-
-    main_file = __file__.split('/')[-1].split('.')[0]
-    os.system(f"{gunicorn} -c gun.py {main_file}:app")
+# if __name__ == '__main__':
+#     import os
+#     import socket
+#
+#     me = socket.gethostname() == 'yuanjie-Mac.local'
+#     gunicorn = "gunicorn" if me else "/opt/soft/python3/bin/gunicorn"
+#
+#     main_file = __file__.split('/')[-1].split('.')[0]
+#     os.system(f"{gunicorn} -c gun.py {main_file}:app")
 
 # gunicorn main:app -b 0.0.0.0:8000  -w 4 -k uvicorn.workers.UvicornH11Worker --daemon
